summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/kformula/main.cc2
-rw-r--r--lib/kofficecore/KoApplication.cpp4
-rw-r--r--lib/kofficecore/KoApplication.h2
-rw-r--r--lib/kofficecore/KoDocument.h6
-rw-r--r--lib/kofficecore/tests/korecttest.cpp2
-rw-r--r--lib/kofficeui/KoKoolBar.cpp2
-rw-r--r--lib/kofficeui/tests/coloraction_test.cpp2
-rw-r--r--lib/koproperty/test/main.cpp2
-rw-r--r--lib/kotext/kohyphen/kohyphentest.cpp2
-rw-r--r--lib/kotext/tests/kobordertest.cpp4
-rw-r--r--lib/kotext/tests/kotextformattertest.cpp2
-rw-r--r--lib/kross/main/wdgscriptsmanager.cpp2
-rw-r--r--lib/kross/runner/main.cpp8
-rw-r--r--lib/kross/test/main.cpp6
-rw-r--r--lib/store/tests/storage_test.cpp2
-rw-r--r--lib/store/tests/storedroptest.cpp4
16 files changed, 26 insertions, 26 deletions
diff --git a/lib/kformula/main.cc b/lib/kformula/main.cc
index a08cecd9..966404ed 100644
--- a/lib/kformula/main.cc
+++ b/lib/kformula/main.cc
@@ -244,7 +244,7 @@ int main(int argc, char** argv)
TDECmdLineArgs::init(argc, argv, &aboutData);
TDECmdLineArgs::addCmdLineOptions(options);
- KApplication app;
+ TDEApplication app;
app.connect(&app, TQT_SIGNAL(lastWindowClosed()), &app, TQT_SLOT(quit()));
diff --git a/lib/kofficecore/KoApplication.h b/lib/kofficecore/KoApplication.h
index 1682b245..87a711f2 100644
--- a/lib/kofficecore/KoApplication.h
+++ b/lib/kofficecore/KoApplication.h
@@ -39,7 +39,7 @@ class KoApplicationPrivate;
* If the last mainwindow becomes closed, KoApplication automatically
* calls TQApplication::quit.
*/
-class KOFFICECORE_EXPORT KoApplication : public KApplication
+class KOFFICECORE_EXPORT KoApplication : public TDEApplication
{
Q_OBJECT
diff --git a/lib/kofficecore/KoDocument.h b/lib/kofficecore/KoDocument.h
index f521607b..63fd47c9 100644
--- a/lib/kofficecore/KoDocument.h
+++ b/lib/kofficecore/KoDocument.h
@@ -181,7 +181,7 @@ public:
/**
* @brief Used by KoApplication, and by KoMainWindow, when no document exists yet.
*
- * With the help of @p instance or KApplication::instance() this
+ * With the help of @p instance or TDEApplication::instance() this
* method figures out which .desktop file matches this application. In this
* file it searches for the "X-TDE-NativeMimeType" entry and returns it.
*
@@ -193,7 +193,7 @@ public:
/**
* Used by KoMainWindow, when no document exists yet.
*
- * With the help of @p instance or KApplication::instance() this
+ * With the help of @p instance or TDEApplication::instance() this
* method figures out which .desktop file matches this application. In this
* file it searches for the "X-TDE-ExtraNativeMimeTypes" entry and returns it.
*
@@ -203,7 +203,7 @@ public:
static TQStringList readExtraNativeMimeTypes( KInstance *instance = 0 );
/**
- * With the help of @p instance or KApplication::instance() this
+ * With the help of @p instance or TDEApplication::instance() this
* method figures out which .desktop file matches this application,
* and returns the KService instance for it.
*/
diff --git a/lib/kofficecore/tests/korecttest.cpp b/lib/kofficecore/tests/korecttest.cpp
index f1a1fd89..6866e176 100644
--- a/lib/kofficecore/tests/korecttest.cpp
+++ b/lib/kofficecore/tests/korecttest.cpp
@@ -35,7 +35,7 @@ bool check(TQString txt, TQString a, TQString b)
int main(int argc, char *argv[])
{
- KApplication app(argc,argv,"korecttest",false,false);
+ TDEApplication app(argc,argv,"korecttest",false,false);
KoRect emptyRect;
check( "KoRect() is null", emptyRect.isNull(), true );
diff --git a/lib/kofficeui/KoKoolBar.cpp b/lib/kofficeui/KoKoolBar.cpp
index 1db0ee9b..ce848874 100644
--- a/lib/kofficeui/KoKoolBar.cpp
+++ b/lib/kofficeui/KoKoolBar.cpp
@@ -462,7 +462,7 @@ void KoKoolBarItem::press()
int main( int argc, char **argv )
{
- KApplication app( argc, argv );
+ TDEApplication app( argc, argv );
KoKoolBar bar;
int file = bar.insertGroup("File");
TQPixmap pix;
diff --git a/lib/kofficeui/tests/coloraction_test.cpp b/lib/kofficeui/tests/coloraction_test.cpp
index 9dfd066c..3e9c146a 100644
--- a/lib/kofficeui/tests/coloraction_test.cpp
+++ b/lib/kofficeui/tests/coloraction_test.cpp
@@ -102,7 +102,7 @@ int main( int argc, char ** argv )
{
srand( time( 0 ) );
- KApplication a( argc, argv, "KColorAction Test" );
+ TDEApplication a( argc, argv, "KColorAction Test" );
TopLevel *toplevel = new TopLevel( 0, "coloractiontest" );
a.setMainWidget( toplevel );
toplevel->show();
diff --git a/lib/koproperty/test/main.cpp b/lib/koproperty/test/main.cpp
index b28a8034..2ac77391 100644
--- a/lib/koproperty/test/main.cpp
+++ b/lib/koproperty/test/main.cpp
@@ -41,7 +41,7 @@ int main(int argc, char **argv)
about.addAuthor( "Cedric Pasteur", 0, "cedric.pasteur@free.fr" );
TDECmdLineArgs::init(argc, argv, &about);
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app;
+ TDEApplication app;
Test *mainWin = 0;
if (app.isRestored())
diff --git a/lib/kotext/kohyphen/kohyphentest.cpp b/lib/kotext/kohyphen/kohyphentest.cpp
index 96e0bd2d..f756b421 100644
--- a/lib/kotext/kohyphen/kohyphentest.cpp
+++ b/lib/kotext/kohyphen/kohyphentest.cpp
@@ -40,7 +40,7 @@ void check_hyphenation( const TQStringList& tests, const TQStringList& results,
int main (int argc, char ** argv)
{
- KApplication app(argc, argv, "KoHyphenator test");
+ TDEApplication app(argc, argv, "KoHyphenator test");
try {
hypher = KoHyphenator::self();
diff --git a/lib/kotext/tests/kobordertest.cpp b/lib/kotext/tests/kobordertest.cpp
index 6dd37aa4..c4e59ffc 100644
--- a/lib/kotext/tests/kobordertest.cpp
+++ b/lib/kotext/tests/kobordertest.cpp
@@ -47,9 +47,9 @@ private:
int main (int argc, char ** argv)
{
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TDECmdLineArgs::init(argc,argv,"kobordertest", 0, 0, 0, 0);
- KApplication app;
+ TDEApplication app;
KoZoomHandler* zh = new KoZoomHandler();
diff --git a/lib/kotext/tests/kotextformattertest.cpp b/lib/kotext/tests/kotextformattertest.cpp
index 6721f771..38aab237 100644
--- a/lib/kotext/tests/kotextformattertest.cpp
+++ b/lib/kotext/tests/kotextformattertest.cpp
@@ -202,7 +202,7 @@ void KoTextFormatterTest::counterAndBigChar()
int main (int argc, char ** argv)
{
- KApplication app(argc, argv, "KoTextFormatter test");
+ TDEApplication app(argc, argv, "KoTextFormatter test");
// Don't let locale settings lead to different hyphenation output
KGlobal::locale()->setLanguage( TQString::fromLatin1( "en_US" ) );
diff --git a/lib/kross/main/wdgscriptsmanager.cpp b/lib/kross/main/wdgscriptsmanager.cpp
index e521023e..d7234332 100644
--- a/lib/kross/main/wdgscriptsmanager.cpp
+++ b/lib/kross/main/wdgscriptsmanager.cpp
@@ -320,7 +320,7 @@ void WdgScriptsManager::slotUnloadScript()
void WdgScriptsManager::slotGetNewScript()
{
#ifdef KROSS_SUPPORT_NEWSTUFF
- const TQString appname = KApplication::kApplication()->name();
+ const TQString appname = TDEApplication::kApplication()->name();
const TQString type = TQString("%1/script").arg(appname);
if(! d->newstuff) {
diff --git a/lib/kross/test/main.cpp b/lib/kross/test/main.cpp
index f8caf2d8..a42f9f46 100644
--- a/lib/kross/test/main.cpp
+++ b/lib/kross/test/main.cpp
@@ -49,7 +49,7 @@
#include <string>
#include <iostream>
-KApplication *app = 0;
+TDEApplication *app = 0;
@@ -168,7 +168,7 @@ int main(int argc, char **argv)
f.close();
if( args->isSet("gui") ) {
- app = new KApplication();
+ app = new TDEApplication();
TestWindow *mainWin = new TestWindow(interpretername, scriptcode);
app->setMainWidget(mainWin);
mainWin->show();
@@ -176,7 +176,7 @@ int main(int argc, char **argv)
result = app->exec();
}
else {
- app = new KApplication(true, true);
+ app = new TDEApplication(true, true);
runInterpreter(interpretername, scriptcode);
}
}
diff --git a/lib/store/tests/storage_test.cpp b/lib/store/tests/storage_test.cpp
index fdb56b1d..baef1b83 100644
--- a/lib/store/tests/storage_test.cpp
+++ b/lib/store/tests/storage_test.cpp
@@ -206,7 +206,7 @@ int test( const char* testName, KoStore::Backend backend, const TQString& testFi
int main( int argc, char **argv )
{
TDECmdLineArgs::init( argc, argv, "storage_test", "A test for the KoStore classes", "1" );
- KApplication app( argc, argv );
+ TDEApplication app( argc, argv );
// KZip (due to KSaveFile) doesn't support relative filenames
// So use $PWD as base for the paths explicitely.
diff --git a/lib/store/tests/storedroptest.cpp b/lib/store/tests/storedroptest.cpp
index 2845e590..30f756a8 100644
--- a/lib/store/tests/storedroptest.cpp
+++ b/lib/store/tests/storedroptest.cpp
@@ -24,9 +24,9 @@ private:
int main( int argc, char** argv )
{
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TDECmdLineArgs::init(argc, argv, "storedroptest", 0, 0, 0, 0);
- KApplication app;
+ TDEApplication app;
StoreDropTest* window = new StoreDropTest( 0 );
window->resize( 500, 500 );
diff --git a/lib/kofficecore/KoApplication.cpp b/lib/kofficecore/KoApplication.cpp
index 5346ff0a..47861558 100644
--- a/lib/kofficecore/KoApplication.cpp
+++ b/lib/kofficecore/KoApplication.cpp
@@ -56,7 +56,7 @@ public:
};
KoApplication::KoApplication()
- : KApplication( initHack() )
+ : TDEApplication( initHack() )
{
d = new KoApplicationPrivate;
@@ -70,7 +70,7 @@ KoApplication::KoApplication()
m_starting = true;
}
// This gets called before entering KApplication::KApplication
bool KoApplication::initHack()
{
TDECmdLineArgs::addCmdLineOptions( options, I18N_NOOP("KOffice"), "koffice", "kde" );
@@ -70,7 +70,7 @@ KoApplication::KoApplication()
m_starting = true;
}
-// This gets called before entering KApplication::KApplication
+// This gets called before entering TDEApplication::TDEApplication
bool KoApplication::initHack()
{
diff --git a/lib/kross/runner/main.cpp b/lib/kross/runner/main.cpp
index fcff2bb0..74c84cf3 100644
--- a/lib/kross/runner/main.cpp
+++ b/lib/kross/runner/main.cpp
@@ -45,7 +45,7 @@
#define ERROR_UNHALDEDEXCEPTION -5
#define ERROR_EXCEPTION -6
-KApplication* app = 0;
+TDEApplication* app = 0;
int runScriptFile(const TQString& scriptfile)
{
@@ -125,8 +125,8 @@ int main(int argc, char **argv)
return ERROR_HELP;
}
- // Create KApplication instance.
- app = new KApplication( /* allowStyles */ true, /* GUIenabled */ true );
+ // Create TDEApplication instance.
+ app = new TDEApplication( /* allowStyles */ true, /* GUIenabled */ true );
//TQString interpretername = args->getOption("interpreter");
//TQString scriptfilename = args->getOption("scriptfile");
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
break;
}
// Free the KApplication instance and exit the program.
delete app;
return result;
}
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
break;
}
- // Free the KApplication instance and exit the program.
+ // Free the TDEApplication instance and exit the program.
delete app;
return result;